@@ -17,7 +17,6 @@ from argo_workflows.model.csi_volume_source import CSIVolumeSource
 from argo_workflows.model.capabilities import Capabilities
 from argo_workflows.model.ceph_fs_volume_source import CephFSVolumeSource
 from argo_workflows.model.cinder_volume_source import CinderVolumeSource
-from argo_workflows.model.condition import Condition
 from argo_workflows.model.config_map_env_source import ConfigMapEnvSource
 from argo_workflows.model.config_map_key_selector import ConfigMapKeySelector
 from argo_workflows.model.config_map_projection import ConfigMapProjection
@@ -28,7 +27,6 @@ from argo_workflows.model.create_options import CreateOptions
 from argo_workflows.model.downward_api_projection import DownwardAPIProjection
 from argo_workflows.model.downward_api_volume_file import DownwardAPIVolumeFile
 from argo_workflows.model.downward_api_volume_source import DownwardAPIVolumeSource
-from argo_workflows.model.duration import Duration
 from argo_workflows.model.empty_dir_volume_source import EmptyDirVolumeSource
 from argo_workflows.model.env_from_source import EnvFromSource
 from argo_workflows.model.env_var import EnvVar
@@ -48,65 +46,6 @@ from argo_workflows.model.flocker_volume_source import FlockerVolumeSource
 from argo_workflows.model.gce_persistent_disk_volume_source import GCEPersistentDiskVolumeSource
 from argo_workflows.model.grpc_action import GRPCAction
 from argo_workflows.model.git_repo_volume_source import GitRepoVolumeSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_aws_credentials import GithubComArgoprojLabsArgoDataflowApiV1alpha1AWSCredentials
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_aws_endpoint import GithubComArgoprojLabsArgoDataflowApiV1alpha1AWSEndpoint
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_abstract_step import GithubComArgoprojLabsArgoDataflowApiV1alpha1AbstractStep
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_abstract_volume_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1AbstractVolumeSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_backoff import GithubComArgoprojLabsArgoDataflowApiV1alpha1Backoff
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_cat import GithubComArgoprojLabsArgoDataflowApiV1alpha1Cat
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_code import GithubComArgoprojLabsArgoDataflowApiV1alpha1Code
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_container import GithubComArgoprojLabsArgoDataflowApiV1alpha1Container
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_cron import GithubComArgoprojLabsArgoDataflowApiV1alpha1Cron
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_db_data_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1DBDataSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_db_data_source_from import GithubComArgoprojLabsArgoDataflowApiV1alpha1DBDataSourceFrom
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_db_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1DBSink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_db_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1DBSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_database import GithubComArgoprojLabsArgoDataflowApiV1alpha1Database
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_dedupe import GithubComArgoprojLabsArgoDataflowApiV1alpha1Dedupe
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_expand import GithubComArgoprojLabsArgoDataflowApiV1alpha1Expand
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_filter import GithubComArgoprojLabsArgoDataflowApiV1alpha1Filter
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_flatten import GithubComArgoprojLabsArgoDataflowApiV1alpha1Flatten
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_git import GithubComArgoprojLabsArgoDataflowApiV1alpha1Git
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_group import GithubComArgoprojLabsArgoDataflowApiV1alpha1Group
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_http_header import GithubComArgoprojLabsArgoDataflowApiV1alpha1HTTPHeader
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_http_header_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1HTTPHeaderSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_http_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1HTTPSink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_http_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1HTTPSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_interface import GithubComArgoprojLabsArgoDataflowApiV1alpha1Interface
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_jet_stream import GithubComArgoprojLabsArgoDataflowApiV1alpha1JetStream
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_jet_stream_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1JetStreamSink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_jet_stream_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1JetStreamSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_kafka import GithubComArgoprojLabsArgoDataflowApiV1alpha1Kafka
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_kafka_config import GithubComArgoprojLabsArgoDataflowApiV1alpha1KafkaConfig
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_kafka_net import GithubComArgoprojLabsArgoDataflowApiV1alpha1KafkaNET
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_kafka_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1KafkaSink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_kafka_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1KafkaSource
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_log import GithubComArgoprojLabsArgoDataflowApiV1alpha1Log
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_map import GithubComArgoprojLabsArgoDataflowApiV1alpha1Map
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_metadata import GithubComArgoprojLabsArgoDataflowApiV1alpha1Metadata
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_nats_auth import GithubComArgoprojLabsArgoDataflowApiV1alpha1NATSAuth
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_pipeline import GithubComArgoprojLabsArgoDataflowApiV1alpha1Pipeline
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_pipeline_list import GithubComArgoprojLabsArgoDataflowApiV1alpha1PipelineList
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_pipeline_spec import GithubComArgoprojLabsArgoDataflowApiV1alpha1PipelineSpec
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_pipeline_status import GithubComArgoprojLabsArgoDataflowApiV1alpha1PipelineStatus
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_s3 import GithubComArgoprojLabsArgoDataflowApiV1alpha1S3
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_s3_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1S3Sink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_s3_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1S3Source
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_sasl import GithubComArgoprojLabsArgoDataflowApiV1alpha1SASL
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_sql_action import GithubComArgoprojLabsArgoDataflowApiV1alpha1SQLAction
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_sql_statement import GithubComArgoprojLabsArgoDataflowApiV1alpha1SQLStatement
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_stan import GithubComArgoprojLabsArgoDataflowApiV1alpha1STAN
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_scale import GithubComArgoprojLabsArgoDataflowApiV1alpha1Scale
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_sidecar import GithubComArgoprojLabsArgoDataflowApiV1alpha1Sidecar
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1Sink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1Source
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_step import GithubComArgoprojLabsArgoDataflowApiV1alpha1Step
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_step_spec import GithubComArgoprojLabsArgoDataflowApiV1alpha1StepSpec
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_step_status import GithubComArgoprojLabsArgoDataflowApiV1alpha1StepStatus
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_storage import GithubComArgoprojLabsArgoDataflowApiV1alpha1Storage
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_tls import GithubComArgoprojLabsArgoDataflowApiV1alpha1TLS
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_volume_sink import GithubComArgoprojLabsArgoDataflowApiV1alpha1VolumeSink
-from argo_workflows.model.github_com_argoproj_labs_argo_dataflow_api_v1alpha1_volume_source import GithubComArgoprojLabsArgoDataflowApiV1alpha1VolumeSource
 from argo_workflows.model.glusterfs_volume_source import GlusterfsVolumeSource
 from argo_workflows.model.google_protobuf_any import GoogleProtobufAny
 from argo_workflows.model.group_version_resource import GroupVersionResource
@@ -133,6 +72,7 @@ from argo_workflows.model.io_argoproj_events_v1alpha1_basic_auth import IoArgopr
 from argo_workflows.model.io_argoproj_events_v1alpha1_bitbucket_auth import IoArgoprojEventsV1alpha1BitbucketAuth
 from argo_workflows.model.io_argoproj_events_v1alpha1_bitbucket_basic_auth import IoArgoprojEventsV1alpha1BitbucketBasicAuth
 from argo_workflows.model.io_argoproj_events_v1alpha1_bitbucket_event_source import IoArgoprojEventsV1alpha1BitbucketEventSource
+from argo_workflows.model.io_argoproj_events_v1alpha1_bitbucket_repository import IoArgoprojEventsV1alpha1BitbucketRepository
 from argo_workflows.model.io_argoproj_events_v1alpha1_bitbucket_server_event_source import IoArgoprojEventsV1alpha1BitbucketServerEventSource
 from argo_workflows.model.io_argoproj_events_v1alpha1_bitbucket_server_repository import IoArgoprojEventsV1alpha1BitbucketServerRepository
 from argo_workflows.model.io_argoproj_events_v1alpha1_calendar_event_source import IoArgoprojEventsV1alpha1CalendarEventSource
@@ -186,6 +126,7 @@ from argo_workflows.model.io_argoproj_events_v1alpha1_pulsar_event_source import
 from argo_workflows.model.io_argoproj_events_v1alpha1_pulsar_trigger import IoArgoprojEventsV1alpha1PulsarTrigger
 from argo_workflows.model.io_argoproj_events_v1alpha1_rate_limit import IoArgoprojEventsV1alpha1RateLimit
 from argo_workflows.model.io_argoproj_events_v1alpha1_redis_event_source import IoArgoprojEventsV1alpha1RedisEventSource
+from argo_workflows.model.io_argoproj_events_v1alpha1_redis_stream_event_source import IoArgoprojEventsV1alpha1RedisStreamEventSource
 from argo_workflows.model.io_argoproj_events_v1alpha1_resource import IoArgoprojEventsV1alpha1Resource
 from argo_workflows.model.io_argoproj_events_v1alpha1_resource_event_source import IoArgoprojEventsV1alpha1ResourceEventSource
 from argo_workflows.model.io_argoproj_events_v1alpha1_resource_filter import IoArgoprojEventsV1alpha1ResourceFilter
@@ -222,23 +163,36 @@ from argo_workflows.model.io_argoproj_events_v1alpha1_url_artifact import IoArgo
 from argo_workflows.model.io_argoproj_events_v1alpha1_value_from_source import IoArgoprojEventsV1alpha1ValueFromSource
 from argo_workflows.model.io_argoproj_events_v1alpha1_watch_path_config import IoArgoprojEventsV1alpha1WatchPathConfig
 from argo_workflows.model.io_argoproj_events_v1alpha1_webhook_context import IoArgoprojEventsV1alpha1WebhookContext
+from argo_workflows.model.io_argoproj_events_v1alpha1_webhook_event_source import IoArgoprojEventsV1alpha1WebhookEventSource
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_archive_strategy import IoArgoprojWorkflowV1alpha1ArchiveStrategy
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_arguments import IoArgoprojWorkflowV1alpha1Arguments
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_art_gc_status import IoArgoprojWorkflowV1alpha1ArtGCStatus
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact import IoArgoprojWorkflowV1alpha1Artifact
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_gc import IoArgoprojWorkflowV1alpha1ArtifactGC
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_gc_spec import IoArgoprojWorkflowV1alpha1ArtifactGCSpec
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_gc_status import IoArgoprojWorkflowV1alpha1ArtifactGCStatus
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_location import IoArgoprojWorkflowV1alpha1ArtifactLocation
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_node_spec import IoArgoprojWorkflowV1alpha1ArtifactNodeSpec
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_paths import IoArgoprojWorkflowV1alpha1ArtifactPaths
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_repository import IoArgoprojWorkflowV1alpha1ArtifactRepository
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_repository_ref import IoArgoprojWorkflowV1alpha1ArtifactRepositoryRef
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_repository_ref_status import IoArgoprojWorkflowV1alpha1ArtifactRepositoryRefStatus
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_result import IoArgoprojWorkflowV1alpha1ArtifactResult
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifact_result_node_status import IoArgoprojWorkflowV1alpha1ArtifactResultNodeStatus
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifactory_artifact import IoArgoprojWorkflowV1alpha1ArtifactoryArtifact
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_artifactory_artifact_repository import IoArgoprojWorkflowV1alpha1ArtifactoryArtifactRepository
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_azure_artifact import IoArgoprojWorkflowV1alpha1AzureArtifact
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_azure_artifact_repository import IoArgoprojWorkflowV1alpha1AzureArtifactRepository
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_backoff import IoArgoprojWorkflowV1alpha1Backoff
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_basic_auth import IoArgoprojWorkflowV1alpha1BasicAuth
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_cache import IoArgoprojWorkflowV1alpha1Cache
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_client_cert_auth import IoArgoprojWorkflowV1alpha1ClientCertAuth
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_cluster_workflow_template import IoArgoprojWorkflowV1alpha1ClusterWorkflowTemplate
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_cluster_workflow_template_create_request import IoArgoprojWorkflowV1alpha1ClusterWorkflowTemplateCreateRequest
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_cluster_workflow_template_lint_request import IoArgoprojWorkflowV1alpha1ClusterWorkflowTemplateLintRequest
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_cluster_workflow_template_list import IoArgoprojWorkflowV1alpha1ClusterWorkflowTemplateList
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_cluster_workflow_template_update_request import IoArgoprojWorkflowV1alpha1ClusterWorkflowTemplateUpdateRequest
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_collect_event_request import IoArgoprojWorkflowV1alpha1CollectEventRequest
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_condition import IoArgoprojWorkflowV1alpha1Condition
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_container_node import IoArgoprojWorkflowV1alpha1ContainerNode
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_container_set_retry_strategy import IoArgoprojWorkflowV1alpha1ContainerSetRetryStrategy
@@ -268,6 +222,8 @@ from argo_workflows.model.io_argoproj_workflow_v1alpha1_hdfs_artifact import IoA
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_hdfs_artifact_repository import IoArgoprojWorkflowV1alpha1HDFSArtifactRepository
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_http import IoArgoprojWorkflowV1alpha1HTTP
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_http_artifact import IoArgoprojWorkflowV1alpha1HTTPArtifact
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_http_auth import IoArgoprojWorkflowV1alpha1HTTPAuth
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_http_body_source import IoArgoprojWorkflowV1alpha1HTTPBodySource
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_http_header import IoArgoprojWorkflowV1alpha1HTTPHeader
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_http_header_source import IoArgoprojWorkflowV1alpha1HTTPHeaderSource
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_header import IoArgoprojWorkflowV1alpha1Header
@@ -281,6 +237,7 @@ from argo_workflows.model.io_argoproj_workflow_v1alpha1_lifecycle_hook import Io
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_link import IoArgoprojWorkflowV1alpha1Link
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_lint_cron_workflow_request import IoArgoprojWorkflowV1alpha1LintCronWorkflowRequest
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_log_entry import IoArgoprojWorkflowV1alpha1LogEntry
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_manifest_from import IoArgoprojWorkflowV1alpha1ManifestFrom
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_memoization_status import IoArgoprojWorkflowV1alpha1MemoizationStatus
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_memoize import IoArgoprojWorkflowV1alpha1Memoize
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_metadata import IoArgoprojWorkflowV1alpha1Metadata
@@ -292,6 +249,8 @@ from argo_workflows.model.io_argoproj_workflow_v1alpha1_mutex_status import IoAr
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_node_result import IoArgoprojWorkflowV1alpha1NodeResult
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_node_status import IoArgoprojWorkflowV1alpha1NodeStatus
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_node_synchronization_status import IoArgoprojWorkflowV1alpha1NodeSynchronizationStatus
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_o_auth2_auth import IoArgoprojWorkflowV1alpha1OAuth2Auth
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_o_auth2_endpoint_param import IoArgoprojWorkflowV1alpha1OAuth2EndpointParam
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_oss_artifact import IoArgoprojWorkflowV1alpha1OSSArtifact
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_oss_artifact_repository import IoArgoprojWorkflowV1alpha1OSSArtifactRepository
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_oss_lifecycle_rule import IoArgoprojWorkflowV1alpha1OSSLifecycleRule
@@ -302,7 +261,9 @@ from argo_workflows.model.io_argoproj_workflow_v1alpha1_pod_gc import IoArgoproj
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_prometheus import IoArgoprojWorkflowV1alpha1Prometheus
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_raw_artifact import IoArgoprojWorkflowV1alpha1RawArtifact
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_resource_template import IoArgoprojWorkflowV1alpha1ResourceTemplate
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_resubmit_archived_workflow_request import IoArgoprojWorkflowV1alpha1ResubmitArchivedWorkflowRequest
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_retry_affinity import IoArgoprojWorkflowV1alpha1RetryAffinity
+from argo_workflows.model.io_argoproj_workflow_v1alpha1_retry_archived_workflow_request import IoArgoprojWorkflowV1alpha1RetryArchivedWorkflowRequest
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_retry_strategy import IoArgoprojWorkflowV1alpha1RetryStrategy
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_s3_artifact import IoArgoprojWorkflowV1alpha1S3Artifact
 from argo_workflows.model.io_argoproj_workflow_v1alpha1_s3_artifact_repository import IoArgoprojWorkflowV1alpha1S3ArtifactRepository
@@ -380,9 +341,6 @@ from argo_workflows.model.persistent_volume_claim_status import PersistentVolume
 from argo_workflows.model.persistent_volume_claim_template import PersistentVolumeClaimTemplate
 from argo_workflows.model.persistent_volume_claim_volume_source import PersistentVolumeClaimVolumeSource
 from argo_workflows.model.photon_persistent_disk_volume_source import PhotonPersistentDiskVolumeSource
-from argo_workflows.model.pipeline_log_entry import PipelineLogEntry
-from argo_workflows.model.pipeline_pipeline_watch_event import PipelinePipelineWatchEvent
-from argo_workflows.model.pipeline_step_watch_event import PipelineStepWatchEvent
 from argo_workflows.model.pod_affinity import PodAffinity
 from argo_workflows.model.pod_affinity_term import PodAffinityTerm
 from argo_workflows.model.pod_anti_affinity import PodAntiAffinity
@@ -418,9 +376,6 @@ from argo_workflows.model.stream_result_of_eventsource_event_source_watch_event
 from argo_workflows.model.stream_result_of_eventsource_log_entry import StreamResultOfEventsourceLogEntry
 from argo_workflows.model.stream_result_of_io_argoproj_workflow_v1alpha1_log_entry import StreamResultOfIoArgoprojWorkflowV1alpha1LogEntry
 from argo_workflows.model.stream_result_of_io_argoproj_workflow_v1alpha1_workflow_watch_event import StreamResultOfIoArgoprojWorkflowV1alpha1WorkflowWatchEvent
-from argo_workflows.model.stream_result_of_pipeline_log_entry import StreamResultOfPipelineLogEntry
-from argo_workflows.model.stream_result_of_pipeline_pipeline_watch_event import StreamResultOfPipelinePipelineWatchEvent
-from argo_workflows.model.stream_result_of_pipeline_step_watch_event import StreamResultOfPipelineStepWatchEvent
 from argo_workflows.model.stream_result_of_sensor_log_entry import StreamResultOfSensorLogEntry
 from argo_workflows.model.stream_result_of_sensor_sensor_watch_event import StreamResultOfSensorSensorWatchEvent
 from argo_workflows.model.sysctl import Sysctl
